@@ -1,7 +1,7 @@
 package PERLANCAR::HTML::Tree::Examples;
 
-our $DATE = '2016-04-03'; # DATE
-our $VERSION = '1.000.002'; # VERSION
+our $DATE = '2016-04-07'; # DATE
+our $VERSION = '1.0.3'; # VERSION
 
 use 5.010001;
 use strict;
@@ -84,8 +84,6 @@ sub gen_sample_data {
     );
 }
 
-*gen_sample_html = \&gen_sample_data;
-
 1;
 # ABSTRACT: Generate sample HTML document
 
@@ -101,7 +99,7 @@ PERLANCAR::HTML::Tree::Examples - Generate sample HTML document
 
 =head1 VERSION
 
-This document describes version 1.000.002 of PERLANCAR::HTML::Tree::Examples (from Perl distribution PERLANCAR-HTML-Tree-Examples), released on 2016-04-03.
+This document describes version 1.0.3 of PERLANCAR::HTML::Tree::Examples (from Perl distribution PERLANCAR-HTML-Tree-Examples), released on 2016-04-07.
 
 =head1 SYNOPSIS
 
@@ -210,8 +208,6 @@ C<medium1> is a document of depth 7 and ~20k elements.
 
 Return value:  (str)
 
-=for Pod::Coverage ^(gen_sample_html)$
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/PERLANCAR-HTML-Tree-Examples>.
